pub struct FatalError;Expand description
An unrecoverable error, that can occur during disk I/O or writing memory. All data in the store should be considered corrupy and the application receiving this error should probably terminate.