pub enum PrefixStoreError {
NodeCreationMaxRetryError,
NodeNotFound,
StoreNotReadyError,
FatalError,
PathSelectionOutdated,
PrefixNotFound,
PrefixLengthInvalid,
BestPathNotFound,
RecordNotInMemory,
PersistFailed,
StatusUnknown,
}Expand description
Possible errors returned by methods on a RIB. Most of these errors are
Variants
NodeCreationMaxRetryError
There is too much contention while creating a node: the store has given up. The method or function returning this error can be safely retries.
NodeNotFound
A node that does not exist (yet), maybe due to contention. The function or method causing this error can be safely retried.
StoreNotReadyError
The method returning this error presupposes a condition that has not been met, and may never be met. Retrying is safe, but may result in the same error. Therefore it should probably be retried only once.
FatalError
An unrecoverable error occurred, most probably during disk IO, or a
poisoned lock while writing. The store is probably corrupt. The caller
should terminate the store, and probably also terminate itself. This
error variant is the same as the FatalError type, but is used as a
return for methods that can also return non-fatal errors.
PathSelectionOutdated
A best path was requested, but the selection procedure was performed on a route set that is now stale. A new best path calculation over the set should be performed before retrying.
PrefixNotFound
The requested prefix was not found in the store.
PrefixLengthInvalid
The requested prefix length cannot exist.
BestPathNotFound
A best path was requested, but it was never calculated. Perform a best path selection first, before retrying.
RecordNotInMemory
A record was specifically requested from the in-memory data structure, but the record is not in memory. It may be persisted to disk.
PersistFailed
The method returning this error was trying to persist records to disk but failed. Retrying is safe, but may be yield the same result.
StatusUnknown
A status for a record was requested, but it was never set.